@@ -24,22 +24,27 @@ import os
 import sys
 import time
 import binascii
+import traceback
 import struct
 import subprocess
 
 import pylink
 
+try:
+    import bflb_path
+except ImportError:
+    from libs import bflb_path
 from libs import bflb_utils
 from libs.bflb_utils import app_path
 
 python_version = struct.calcsize("P") * 8
 
 if python_version == 64:
-    path_dll = os.path.join(app_path, "JLink_x64.dll")
+    path_dll = os.path.join(app_path, "utils/jlink", "JLink_x64.dll")
 else:
-    path_dll = os.path.join(app_path, "JLinkARM.dll")
+    path_dll = os.path.join(app_path, "utils/jlink", "JLinkARM.dll")
     
-jlink_path = os.path.join(app_path, "JLink.exe")
+jlink_path = os.path.join(app_path, "utils/jlink", "JLink.exe")
 
 
 class BflbJLinkPort(object):
@@ -51,9 +56,10 @@ class BflbJLinkPort(object):
         self._jlink_data_addr = "20000004"
         self._inited = False
         self._chiptype = "bl60x"
+        self._chipname = "bl60x"
         self._jlink_run_addr = "22010000"
 
-    def if_init(self, device, rate, chiptype="bl60x"):
+    def if_init(self, device, rate, chiptype="bl60x", chipname="bl60x"):
         if self._inited is False:
             # jlink_cfg_module = __import__(chiptype + ".jlink_load_cfg")
             # jlink_cfg_module = __import__("libs." + chiptype + ".jlink_load_cfg", fromlist=["jlink_load_cfg"])
@@ -78,6 +84,7 @@ class BflbJLinkPort(object):
             self._jlink.connect(core_type, rate)
             self._inited = True
             self._chiptype = chiptype
+            self._chipname = chipname
             self._jlink_run_addr = sub_module.jlink_load_cfg.jlink_run_addr
 
     def if_set_rx_timeout(self, val):
@@ -96,7 +103,10 @@ class BflbJLinkPort(object):
             return False
 
     def reset_cpu(self, ms=0, halt=True):
-        self._jlink.reset(ms, halt)
+        if self._chiptype != "bl60x":
+            self._jlink.set_reset_pin_low()
+            self._jlink.set_reset_pin_high()
+        return self._jlink.reset(ms, False)
 
     def set_pc_msp(self, pc, msp):
         if self._jlink.halted() is False:
@@ -238,7 +248,11 @@ class BflbJLinkPort(object):
                      do_reset=False,
                      reset_hold_time=100,
                      shake_hand_delay=100,
-                     reset_revert=True):
+                     reset_revert=True,
+                     cutoff_time=0,
+                     shake_hand_retry=2,
+                     iap_timeout=0,
+                     boot_load=False):
         self.if_write(bytearray(1))
         success, ack = self.if_read(2)
         bflb_utils.printf(binascii.hexlify(ack))
@@ -258,6 +272,8 @@ class BflbJLinkPort(object):
             return ack.decode("utf-8")
         if ack.find(b'\x4F') != -1 or ack.find(b'\x4B') != -1:
             return "OK"
+        elif ack.find(b'\x50') != -1 or ack.find(b'\x44') != -1:
+            return "PD"
         success, err_code = self.if_read(4)
         if success == 0:
             bflb_utils.printf("err_code:" + str(binascii.hexlify(err_code)))
@@ -265,7 +281,7 @@ class BflbJLinkPort(object):
         err_code_str = str(binascii.hexlify(err_code[3:4] + err_code[2:3]).decode('utf-8'))
         ack = "FL"
         try:
-            ret = ack + err_code_str + "(" + bflb_utils.get_bflb_error_code[err_code_str] + ")"
+            ret = ack + err_code_str + "(" + bflb_utils.get_bflb_error_code(err_code_str) + ")"
         except Exception:
             ret = ack + err_code_str + " unknown"
         bflb_utils.printf(ret)
@@ -295,3 +311,15 @@ class BflbJLinkPort(object):
         bflb_utils.printf("Not ack OK")
         bflb_utils.printf(ack)
         return ack, None
+
+if __name__ == '__main__':
+    try:
+        eflash_loader_t = BflbJLinkPort()
+        eflash_loader_t.if_init("", 1000, "bl602")
+        bflb_utils.printf("reset test")
+        res = eflash_loader_t.reset_cpu(0, False)
+        bflb_utils.printf(res)
+    except Exception as e:
+            NUM_ERR = 5
+            bflb_utils.printf(e)
+            traceback.print_exc(limit=NUM_ERR, file=sys.stdout)
\ No newline at end of file
